fabutils-cciw
=============

Small library of reusable utilities for fabfiles, used by:

- https://github.com/cciw-uk/cciw.co.uk
- https://github.com/learnscripture/learnscripture.net/

See comments in src/fabutils/connections.py for some rationale behind
design/constraints of these utilities.
